/*
Required input files:	
	MEPS_data.dta

Output files:
	table_5_raw.csv
	table_7.csv
	figure_meps_main_raw.csv
*/

*****************************
* Initialization
*****************************

* Set this local equal to the folder location for this script, e.g., "C:/Users/name/myfolder/"
local workdir ""

clear
set more off
tempfile meps_tmp1 meps_tmp2 meps_tmp3

* Set the flag equal to 1 to run that analysis, and equal to 0 otherwise
local table_2 = 1
local table_5 = 1
local table_6 = 1
local table_7 = 1
local figure_meps = 1

*****************************
* Table 2
*****************************

if `table_2'==1 {
	
	use "`workdir'data/MEPS_data.dta", clear
	
	* Average drug use and expenditure for ages 66-75 during pre-period
	* Insured vs uninsured
	* Drug use or expenditure for specific cause-of-death (i.e., cardio)
	keep if inrange(year, 2001, 2004) 
	keep if inrange(age, 66, 75)
	
	table rxanycov [pw=perwt], c(mean cardio)

}

*****************************
* Table 5
*****************************

if `table_5'==1 {

	local replace "replace"	

	use "`workdir'data/MEPS_data.dta", clear
	
	* Re-define specific cause-of-death for the table
	* Number of drugs
	ren cardio a00Cardiovascular
	ren heart a01HeartDisease
	ren hrtfailure a02HeartFailure
	ren imht a03IschemicandHypertension
	ren oheart a04OtherHeart
	ren stroke a05Stroke
	ren pvd a06PeripheralVascular
	ren ocvd a07OtherCVD
	ren cancer b00Cancer
	ren cdigestive b01Digestive
	ren clung b02Lung
	ren cbreast b03Breast
	ren cgenital b04Genital
	ren clymph b05Lymph
	ren cbladder b06Bladder
	ren cthyroid b07Thyroid
	ren ocancer b08OtherCancer
	ren other c00OtherDiseases
	ren diabete c01Diabetes
	ren alzheim c02Alzheimers
	ren lowresp c03ChronicLowerRespiratory
	ren kidney c04Kidney
	ren renalfailure c05RenalFailure
	ren okidney c06OtherKidney
	ren respp c07UpperRespiratory
	ren respfailure c08RespiratoryFailure
	ren lipmeta c09LipidMetabolism
	ren digestsys c10DigestiveSystem
	ren parkinsons c11Parkinsons
	ren pneum c12Pneumonia
	ren othmin c13Other
	ren external d00ExternalCauses
	ren etransport d01TransportAccidents
	ren nontransport d02NontransportAccidents
	ren falls d03Falls
	ren drown d04Drowning
	ren fire d05Fires	
	ren poison d06Poison
	ren codemiss e00Unspecified
	ren anysum f00Total
		
	* Expenditures
	ren totamt_cardio g00Cardiovascular
	ren totamt_heart g01HeartDisease
	ren totamt_hrtfailure g02HeartFailure
	ren totamt_imht g03IschemicandHypertension
	ren totamt_oheart g04OtherHeart
	ren totamt_stroke g05Stroke
	ren totamt_pvd g06PeripheralVascular
	ren totamt_ocvd g07OtherCVD
	ren totamt_cancer h00Cancer
	ren totamt_cdigestive h01Digestive
	ren totamt_clung h02Lung
	ren totamt_cbreast h03Breast
	ren totamt_cgenital h04Genital
	ren totamt_clymph h05Lymph
	ren totamt_cbladder h06Bladder
	ren totamt_cthyroid h07Thyroid
	ren totamt_ocancer h08OtherCancer
	ren totamt_other i00OtherDiseases
	ren totamt_diabete i01Diabetes
	ren totamt_alzheim i02Alzheimers
	ren totamt_lowresp i03ChronicLowerRespiratory
	ren totamt_kidney i04Kidney
	ren totamt_renalfailure i05RenalFailure
	ren totamt_okidney i06OtherKidney
	ren totamt_respp i07UpperRespiratory
	ren totamt_respfailure i08RespiratoryFailure
	ren totamt_lipmeta i09LipidMetabolism
	ren totamt_digestsys i10DigestiveSystem
	ren totamt_parkinsons i11Parkinsons
	ren totamt_pneum i12Pneumonia
	ren totamt_othmin i13Other
	ren totamt_external j00ExternalCauses
	ren totamt_etransport j01TransportAccidents
	ren totamt_nontransport j02NontransportAccidents
	ren totamt_fll j03Falls
	ren totamt_drwn j04Drowning
	ren totamt_fre j05Fires
	ren totamt_psn j06Poison
	ren totamt_codemiss k00Unspecified
	ren totamt_any l00Total
		
	* Drug use regressions by specific cause-of-death	
	* Drug expenditure (dollar amount) regressions by specific cause-of-death
	xi i.postpartd*elderly
	foreach cause in "a00Cardiovascular" "a01HeartDisease" "a02HeartFailure" "a03IschemicandHypertension" "a04OtherHeart" "a05Stroke" "a06PeripheralVascular" "a07OtherCVD" "b00Cancer" "b01Digestive" "b02Lung" "b03Breast" "b04Genital" "b05Lymph" "b06Bladder" ///
					 "b07Thyroid" "b08OtherCancer" "c00OtherDiseases" "c01Diabetes" "c02Alzheimers" "c03ChronicLowerRespiratory" "c04Kidney" "c05RenalFailure" "c06OtherKidney" "c07UpperRespiratory" "c08RespiratoryFailure" "c09LipidMetabolism" "c10DigestiveSystem" ///
					 "c11Parkinsons" "c12Pneumonia" "c13Other" "d00ExternalCauses" "e00Unspecified" "f00Total" "g00Cardiovascular" "g01HeartDisease" "g02HeartFailure" "g03IschemicandHypertension" "g04OtherHeart" "g05Stroke" "g06PeripheralVascular" /// 
					 "g07OtherCVD" "h00Cancer" "h01Digestive" "h02Lung" "h03Breast" "h04Genital" "h05Lymph" "h06Bladder" "h07Thyroid" "h08OtherCancer" "i00OtherDiseases" "i01Diabetes" "i02Alzheimers" "i03ChronicLowerRespiratory" "i04Kidney" "i05RenalFailure" ///
					 "i06OtherKidney" "i07UpperRespiratory" "i08RespiratoryFailure" "i09LipidMetabolism" "i10DigestiveSystem" "i11Parkinsons" "i12Pneumonia" "i13Other" "j00ExternalCauses" "k00Unspecified" "l00Total" {
					 		
		reg `cause' i.elderly _IposXelder* i.year i.marstat i.racerecode i.educrecode i.sex i.region i.iquintile [pw=perwt], vce(cluster hhage)
		estimates store `cause'
		
		regsave using "`meps_tmp1'", tstat pval ci ///
		addlabel(deathcause, `cause') `replace'
		local replace "append"

	}

* Format and outsheet results for use in PivotTable
use "`meps_tmp1'", clear
replace var = subinstr(var,"foreign:","",.)
outsheet using "`workdir'results/table_5_raw.csv", comma replace

}	

*****************************
* Table 6
*****************************

if `table_6'==1 {

	use "`workdir'data/MEPS_data.dta", clear
	
	* MEPS descriptive statistics for ages 66-75 in 2003
	gen nonwhite=(racerecode!=1)
	gen male=(sex==1)
	drop if educrecode==.
	
	table iquintile [pw=perwt] if year==2003 & inrange(age, 66, 75), c(mean medicaid mean nonwhite mean male mean rxanycov)
	gen ct=1
	table iquintile if year==2003 & inrange(age, 66, 75), c(sum ct)

}	

*****************************
* Table 7
*****************************

if `table_7'==1 {

	local replace "replace"	

	* MEPS drug use regressions by income gender race 	
	use "`workdir'data/MEPS_data.dta", clear
	
	* Define variables and interactions for regression
	gen eldXpost=elderly*postpartd
	gen eldXqui=elderly*iquintile
	gen white=(racerecode==1) 
	replace white=2 if white==0   
	gen eXr=elderly*white
	gen eXg=elderly*sex
		
	* Run regressions
	xi i.eldXqui*i.postpartd i.eXg*i.postpartd i.eXr*i.postpartd 
	foreach regressors in "_IeldXpos* i.elderly i.year i.marstat i.racerecode i.educrecode i.sex i.region i.iquintile [pw=perwt]" /// 
						  "_IeXgXpos* i.elderly i.year i.marstat i.racerecode i.educrecode i.sex i.region i.iquintile [pw=perwt]" /// 
						  "_IeXrXpos* i.elderly i.year i.marstat i.racerecode i.educrecode i.sex i.region i.iquintile [pw=perwt]" {			
	
	reg anysum `regressors', vce(cluster hhage)
	
	regsave using "`meps_tmp2'", tstat pval ci ///
	addlabel(regressors, `regressors') `replace'
	local replace "append"
	}	
	
* Format and outsheet results for use in PivotTable
use "`meps_tmp2'", clear
replace var = subinstr(var,"foreign:","",.)
outsheet using "`workdir'results/table_7_raw.csv", comma replace

}

*****************************
* Figures 5, 6
*****************************

if `figure_meps'==1 {
	
	local replace "replace"	
	
	* MEPS drug use event study by income gender race 	
	foreach cause in "anysum" "cardio" {
		
		use "`workdir'data/MEPS_data.dta", clear
	
		* Define interactions for regression
		gen eldXqui=elderly*iquintile 
		
		* Run regressions
		char year[omit] 2004
		xi i.year*i.eldXqui
		reg `cause' _IyeaXeld* i.elderly i.year i.marstat i.racerecode i.educrecode i.sex i.region i.iquintile [pw=perwt], vce(cluster hhage)
	
		regsave using "`meps_tmp3'", tstat pval ci ///
		addlabel(deathcause, `cause') `replace'
		local replace "append"
	}
	
* Format and outsheet results for use in PivotTable
use "`meps_tmp3'", clear
replace var = subinstr(var,"foreign:","",.)
outsheet using "`workdir'results/figure_meps_main_raw.csv", comma replace

}
